==> h5x-0.1.6.tgz: package/lib/platform/platform-loader.js <==
var path = require("path");
var express = require('express');

var platform_deployer,config,server,platform_dai,logger;

module.exports = function(opts){
    config = opts.config;
    server = opts.server;
    logger = opts.logger;

    platform_dai = require("./platform-dai")({
        db_prefix : config.db_prefix,
        db_uri : config.db_uri,
        logger : logger,
        server : server
    });

    platform_deployer = require('./platform-deployer')(config);

    return {
        load:load_app
    }
}

/*
  绑定主页
*/
function platform_homepage(app_module){

    var tpl_dir = path.resolve(config.root_dir,app_module.app_root,app_module.app_name,"index.html");

    function home_compile(req,res){
        //console.log(req.params);
        var app_id = req.params["appid"];
        var html = platform_deployer.compile(tpl_dir,{
            app_module:app_module,
            app_id:app_id
        });

        res.header("Content-Type","text/html");
        res.end(html);
    }

    //console.log((app_module.pre_url) +app_module.app_name);

    server.get(app_module.pre_url+"/"+app_module.app_name,home_compile);
    server.get(app_module.pre_url+"/"+app_module.app_name+"/:appid",home_compile);
    if(app_module.config.url_alias){
        server.get(app_module.config.url_alias,home_compile);
    }
    


}

/*
  设置静态文件目录
*/
function platform_dev_static(app_module){
    (app_module.config.dev_static || []).forEach(function(static_dir){        
        var url_path = path.join(app_module.pre_url||"/",app_module.app_name,static_dir);
        url_path = url_path.replace(/\\/g,"/");

       // console.dir(app_module);

        //console.log(path.join(config.root_dir,app_module.app_root,app_module.app_name,static_dir));
        //console.log(url_path);
        server.use(url_path,express.static(path.join(config.root_dir,app_module.app_root,app_module.app_name,static_dir)));
    });
}

/*
var dataCache = require("./platform-datacache");
function platform_data_cache(app_module){
    app_module.dataCache = dataCache;
}
*/

/*
  load app
*/
function load_app(pre_url,app_root,app_name){
    logger.info("loading app "+app_name);  

    var app_path = path.join(config.root_dir, app_root,app_name);
    var app_config = require(path.join(app_path,"config.json"));
    //app_config.app_root = app_root;

    var app_module = {
        pre_url:pre_url,
        app_name:app_name,
        app_root:app_root,
        config:app_config
    }



    //数据访问接口

    if(app_config.usedai){
        platform_dai(app_module);
        var app_dai = require(path.join(app_path,"dai"));
        app_dai(app_module);
    }
	
	
	if(app_config.useapi){
        var app_api = require(path.join(app_path,"api"));
        app_api(server);
    }

    //app主页
    platform_homepage(app_module);

    //静态资源（开发模式）
    platform_dev_static(app_module);
    

    /*
    //添加数据缓存
    platform_data_cache(app_module);
    */

    /*
    if(platform_module.onReady){
        platform_module.onReady();
    }*/

    return app_module;
}

==> h5x-0.1.13.tgz: package/lib/platform/platform-loader.js <==
var path = require("path");
var express = require('express');

var platform_deployer,config,server,platform_dai,logger;

module.exports = function(opts){
    config = opts.config;
    server = opts.server;
    logger = opts.logger;

    platform_dai = server.dai = require("./platform-dai")({
        db_prefix : config.db_prefix,
        db_uri : config.db_uri,
        logger : logger,
        server : server
    });

    platform_deployer = require('./platform-deployer')(config);

    return {
        load:load_app
    }
}

/*
  绑定主页
*/
function platform_homepage(app_module){

    var tpl_dir = path.resolve(config.root_dir,app_module.app_root,app_module.app_name,"index.html");

    function home_compile(req,res){
        //console.log(req.params);
        var app_id = req.params["appid"];
        var html = platform_deployer.compile(tpl_dir,{
            app_module:app_module,
            app_id:app_id
        });

        res.header("Content-Type","text/html");
        res.end(html);
    }

    //console.log((app_module.pre_url) +app_module.app_name);

    server.get(app_module.pre_url+"/"+app_module.app_name,home_compile);
    server.get(app_module.pre_url+"/"+app_module.app_name+"/:appid",home_compile);
    if(app_module.config.url_alias){
        server.get(app_module.config.url_alias,home_compile);
    }
    


}

/*
  设置静态文件目录
*/
function platform_dev_static(app_module){
    (app_module.config.dev_static || []).forEach(function(static_dir){        
        var url_path = path.join(app_module.pre_url||"/",app_module.app_name,static_dir);
        url_path = url_path.replace(/\\/g,"/");

       // console.dir(app_module);

        //console.log(path.join(config.root_dir,app_module.app_root,app_module.app_name,static_dir));
        //console.log(url_path);
        server.use(url_path,express.static(path.join(config.root_dir,app_module.app_root,app_module.app_name,static_dir)));
    });
}

/*
var dataCache = require("./platform-datacache");
function platform_data_cache(app_module){
    app_module.dataCache = dataCache;
}
*/

/*
  load app
*/
function load_app(pre_url,app_root,app_name){
    logger.info("loading app "+app_name);  

    var app_path = path.join(config.root_dir, app_root,app_name);
    var app_config = require(path.join(app_path,"config.json"));
    //app_config.app_root = app_root;

    var app_module = {
        pre_url:pre_url,
        app_name:app_name,
        app_root:app_root,
        config:app_config
    }



    //数据访问接口

    if(app_config.usedai){
        platform_dai(app_module);
        var app_dai = require(path.join(app_path,"dai"));
        app_dai(app_module);
    }
	
	
	if(app_config.useapi){
        var app_api = require(path.join(app_path,"api"));
        app_api(server);
    }

    //app主页
    platform_homepage(app_module);

    //静态资源（开发模式）
    platform_dev_static(app_module);
    

    /*
    //添加数据缓存
    platform_data_cache(app_module);
    */

    /*
    if(platform_module.onReady){
        platform_module.onReady();
    }*/

    return app_module;
}
